@@ -1,23 +1,10 @@
 /*
- *  This file is part of the kuiviewer package
- *  Copyright (c) 2003 Richard Moore <rich@kde.org>
- *  Copyright (c) 2003 Ian Reinhart Geiser <geiseri@kde.org>
- *  Copyright (c) 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2003 Richard Moore <rich@kde.org>
+    SPDX-FileCopyrightText: 2003 Ian Reinhart Geiser <geiseri@kde.org>
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #define TRANSLATION_DOMAIN "kuiviewer"
 
@@ -33,7 +20,11 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KLocalizedString>
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+#include <KPluginMetaData>
+#else
 #include <KAboutData>
+#endif
 #include <KPluginFactory>
 
 // Qt
@@ -55,11 +46,17 @@ K_PLUGIN_FACTORY_WITH_JSON(KUIViewerPartFactory, "kuiviewer_part.json",
 
 KUIViewerPart::KUIViewerPart(QWidget* parentWidget,
                              QObject* parent,
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+                             const KPluginMetaData& metaData,
+#endif
                              const QVariantList& /*args*/)
     : KParts::ReadOnlyPart(parent)
     , m_subWindow(nullptr)
     , m_view(nullptr)
 {
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    setMetaData(metaData);
+#else
     // we need an instance
     KAboutData about(QStringLiteral("kuiviewerpart"),
                      i18n("KUIViewerPart"),
@@ -70,6 +67,7 @@ KUIViewerPart::KUIViewerPart(QWidget* parentWidget,
     about.addAuthor(i18n("Ian Reinhart Geiser"), i18n("Original author"), QStringLiteral("geiseri@kde.org"));
     about.addAuthor(i18n("Friedrich W. H. Kossebau"), i18n("Subwindow-like display of UI files"), QStringLiteral("kossebau@kde.org"));
     setComponentData(about);
+#endif
 
     // this should be your custom internal widget
     m_widget = new QMdiArea(parentWidget);
